/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsISupportsPRBool">
 **/

package org.mozilla.xpcom;

public interface nsISupportsPRBool extends nsISupportsPrimitive
{
  public static final String NS_ISUPPORTSPRBOOL_IID =
    "{ddc3b490-4a1c-11d3-9890-006008962422}";

  public boolean getData();

  public void setData(boolean arg1);

  public String toString();

}
